#!/usr/bin/bash
set -e
set -v on
### 本文件为 module 工具的安装脚本,在运行本脚本之前，需要修改本文件的一些配置
### 当前时间：2022年6月24日16:29:27

## 指定 module 安装包的路径（默认与本脚本位于同一路径）
module_pkg_dir=$(dirname $(readlink -f "$0"))
## 指定 module 的版本号
module_version=5.0.1
## 指定 module 的 build 目录(默认与安装包位于同一路径)
module_build_dir=${module_pkg_dir}/../build
## 指定 module 的安装目录
module_install_dir=/usr/qiql/tool/module/${module_version}
## 指定 tcl 脚本工具安装包的路径（默认与本脚本位于同一路径）
tcl_pkg_dir=$(dirname $(readlink -f "$0"))
## 指定 tcl 的版本号
tcl_version=8.5.9
## 指定 tcl 的 build 目录（默认与安装包位于同一路径）
tcl_build_dir=${tcl_pkg_dir}/../build
## 指定 tcl 的安装目录
tcl_install_dir=/usr/qiql/tool/tcl/${tcl_version}
### 指定配置完毕

## 开始安装 tcl
mkdir -p ${tcl_build_dir}
tar -zxvf ${tcl_pkg_dir}/tcl${tcl_version}-src.tar.gz -C ${tcl_build_dir}
cd ${tcl_build_dir}/tcl${tcl_version}/unix
# 必须要进入unix目录才能执行./configure 命令
./configure --prefix=${tcl_install_dir}
make
make install
## 安装 tcl 完毕

## 开始安装 module
mkdir -p ${module_build_dir}
tar -zxvf ${module_pkg_dir}/modules-${module_version}.tar.gz -C ${module_build_dir}
cd ${module_build_dir}/modules-${module_version}
# 按照./configure -h 的说明，--with-tcl参数所指定的tcl的路径应该要有需要包含lib目录，因为此目录下才有 tclConfig.sh 这个文件
./configure --prefix=${module_install_dir} --with-tcl=${tcl_install_dir}/lib
make
make install

echo "module has been installed to " ${module_install_dir}
set +e
### END
